Object subclass: #Application
	instanceVariableNames: 'window canvas editor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphical-Editor-Base'!

!Application methodsFor: 'initialize-release' stamp: 'dd 6/7/2012 10:53'!
initialize
	super initialize.
	self initializeGui.
	self initializeEditor.
	self initializeTools.! !

!Application methodsFor: 'initialize-release' stamp: 'dd 6/6/2012 23:36'!
initializeEditor
	editor:= GraphicsEditor createEditorFor: canvas.
	editor tool: MorphTool defaultMorphTool.
	! !

!Application methodsFor: 'initialize-release' stamp: 'dd 6/6/2012 23:45'!
initializeGui
	window := SystemWindow labelled: 'Graphical Editor'.
	window model: Model new.
	canvas := Morph new.
	window addMorph: canvas frame:(0@0 corner: 1@1).
	window openInWorld.! !

!Application methodsFor: 'initialize-release' stamp: 'yet no classified 6/8/2012 01:20'!
initializeTools
	|handler list |
	list:= OrderedCollection new.
	list add:(LineTool new).
	list add: (MorphTool with:EllipseMorph).
	list add: (MorphTool with: RectangleMorph).
	list add: (MorphTool with: CircleMorph).
	list add: (MorphTool with: MyMorph).
	list add: (MorphTool with: CrossMorph).
	list add: (MorphTool with: DiceMorph).
	handler:= 	ToolHandler createFor:list with:editor.
		handler position: canvas position.
	window addMorph: handler.! !


Morph subclass: #CrossMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphical-Editor-Base'!

!CrossMorph methodsFor: 'as yet unclassified' stamp: 'yet no classified 6/8/2012 01:13'!
drawOn: aCanvas 
    | crossHeight crossWidth horizontalBar verticalBar | 
    crossHeight := self height / 3.0 . 
    crossWidth := self width / 3.0 . 
    horizontalBar := self bounds insetBy: 0 @ crossHeight. 
    verticalBar := self bounds insetBy: crossWidth @ 0. 
    aCanvas fillRectangle: horizontalBar color: self color. 
    aCanvas fillRectangle: verticalBar color: self color! !


BorderedMorph subclass: #DiceMorph
	instanceVariableNames: 'faces diceValue isStopped'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphical-Editor-Base'!

!DiceMorph methodsFor: 'as yet unclassified' stamp: 'yet no classified 6/8/2012 01:19'!
drawDotOn: aCanvas at: aPoint 
    aCanvas 
        fillOval: (Rectangle 
            center: self position + (self extent * aPoint) 
            extent: self extent / 6) 
        color: Color black! !

!DiceMorph methodsFor: 'as yet unclassified' stamp: 'yet no classified 6/8/2012 01:19'!
drawOn: aCanvas 
    super drawOn: aCanvas. 
    (self perform: ('face' , diceValue asString) asSymbol) 
        do: [:aPoint | self drawDotOn: aCanvas at: aPoint]! !

!DiceMorph methodsFor: 'as yet unclassified' stamp: 'yet no classified 6/8/2012 01:18'!
face5 
    ^{0.25@0.25 . 0.75@0.25 . 0.75@0.75 . 0.25@0.75 . 0.5@0.5} ! !

!DiceMorph methodsFor: 'as yet unclassified' stamp: 'yet no classified 6/8/2012 01:16'!
faces: aNumber 
     ^self new faces: aNumber! !

!DiceMorph methodsFor: 'as yet unclassified' stamp: 'yet no classified 6/8/2012 01:18'!
initialize 
    super initialize. 
    self extent: 50 @ 50. 
    self useGradientFill; borderWidth: 2; useRoundedCorners. 
    self setBorderStyle: #complexRaised. 
    self fillStyle direction: self extent. 
    self color: Color green. 
    diceValue := 5. 
    faces := 6. 
    isStopped := false! !


Object subclass: #GraphicsEditor
	instanceVariableNames: 'tool canvas toolHandler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphical-Editor-Base'!

!GraphicsEditor methodsFor: 'accessing' stamp: 'dd 6/5/2012 14:08'!
canvas
	"Answer the value of canvas"

	^ canvas! !

!GraphicsEditor methodsFor: 'accessing' stamp: 'dd 6/5/2012 14:08'!
canvas: anObject
	"Set the value of canvas"

	canvas := anObject! !

!GraphicsEditor methodsFor: 'accessing' stamp: 'dd 6/7/2012 11:18'!
changeTool:tool a:ab b: aa.
	self tool:tool.! !

!GraphicsEditor methodsFor: 'accessing' stamp: 'dd 6/5/2012 14:08'!
tool
	"Answer the value of tool"

	^ tool! !

!GraphicsEditor methodsFor: 'accessing' stamp: 'dd 6/5/2012 14:15'!
tool: aTool
	"Install the new tool"
	tool notNil 
		ifTrue: 
			[tool deinstall].
	tool := aTool.
	tool notNil
		ifTrue:
			[aTool install: canvas].
	self toolChanged.
	! !

!GraphicsEditor methodsFor: 'accessing' stamp: 'dd 6/7/2012 00:02'!
toolHandler
	"Answer the value of toolHandler"

	^ toolHandler! !

!GraphicsEditor methodsFor: 'accessing' stamp: 'dd 6/7/2012 00:02'!
toolHandler: anObject
	"Set the value of toolHandler"

	toolHandler := anObject! !


!GraphicsEditor methodsFor: 'state' stamp: 'dd 6/5/2012 14:15'!
toolChanged! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

GraphicsEditor class
	instanceVariableNames: ''!

!GraphicsEditor class methodsFor: 'instance creation' stamp: 'dd 6/7/2012 10:48'!
createEditorFor: aMorph
	|editor|
	editor := GraphicsEditor new.
	editor canvas: aMorph.
	^editor.! !


Morph subclass: #MyMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphical-Editor-Base'!

!MyMorph methodsFor: 'as yet unclassified' stamp: 'dd 6/7/2012 19:10'!
drawOn: aCanvas
| colors |
colors := color wheel: 6.
colors withIndexDo: [:c :i |
aCanvas fillOval: (self bounds insetBy: 4 * i) color: c].
! !


Object subclass: #Tool
	instanceVariableNames: 'canvas out name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphical-Editor-Base'!

!Tool methodsFor: 'install-deinstall' stamp: 'dd 6/7/2012 11:31'!
deinstall
	self unregisterEvents.! !

!Tool methodsFor: 'install-deinstall' stamp: 'dd 6/5/2012 14:58'!
install: aMorph
	canvas := aMorph.
	self registerEvents.! !

!Tool methodsFor: 'install-deinstall' stamp: 'dd 6/6/2012 22:07'!
registerEvents
	canvas on: #mouseLeaveDragging send: #left to: self.
	canvas on: #mouseEnterDragging send: #entered to: self.
	canvas on: #mouseLeave send: #left to: self.
	canvas on: #mouseEnter send: #entered to: self.! !

!Tool methodsFor: 'install-deinstall' stamp: 'dd 6/6/2012 22:11'!
unregisterEvents
	canvas eventHandler forgetDispatchesTo: #entered.
	canvas eventHandler forgetDispatchesTo: #left..! !


!Tool methodsFor: 'drawing' stamp: 'dd 6/6/2012 22:08'!
entered
	out:=false.! !

!Tool methodsFor: 'drawing' stamp: 'dd 6/7/2012 09:55'!
icon! !

!Tool methodsFor: 'drawing' stamp: 'dd 6/6/2012 22:08'!
left
	out :=true.! !


!Tool methodsFor: 'accessing' stamp: 'dd 6/7/2012 10:01'!
canvas
	"Answer the value of canvas"

	^ canvas! !

!Tool methodsFor: 'accessing' stamp: 'dd 6/7/2012 10:01'!
canvas: anObject
	"Set the value of canvas"

	canvas := anObject! !

!Tool methodsFor: 'accessing' stamp: 'dd 6/7/2012 10:01'!
name: anObject
	"Set the value of name"

	name := anObject! !

!Tool methodsFor: 'accessing' stamp: 'dd 6/7/2012 10:01'!
out
	"Answer the value of out"

	^ out! !

!Tool methodsFor: 'accessing' stamp: 'dd 6/7/2012 10:01'!
out: anObject
	"Set the value of out"

	out := anObject! !

!Tool methodsFor: 'accessing' stamp: 'dd 6/7/2012 10:25'!
view
	^self subclassResponsibility.! !


Tool subclass: #LineTool
	instanceVariableNames: 'line'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphical-Editor-Base'!

!LineTool methodsFor: 'install-deinstall' stamp: 'dd 6/6/2012 22:12'!
registerEvents
	super registerEvents.
	canvas on: #mouseDown send: #start to: self.
	canvas on: #mouseMove send: #move to:self.
	canvas on: #mouseUp send: #end to: self.
	
	! !

!LineTool methodsFor: 'install-deinstall' stamp: 'dd 6/6/2012 22:13'!
unregisterEvents
	super unregisterEvents.
	canvas eventHandler forgetDispatchesTo: #start.
	canvas eventHandler forgetDispatchesTo: #move.
	canvas eventHandler forgetDispatchesTo: #end.
	
	! !


!LineTool methodsFor: 'drawing' stamp: 'dd 6/5/2012 16:44'!
end
	line := nil.
	! !

!LineTool methodsFor: 'drawing' stamp: 'dd 6/7/2012 09:58'!
icon
	^LineMorph new imageForm.! !

!LineTool methodsFor: 'drawing' stamp: 'dd 6/6/2012 22:01'!
move
	|pos|
	out ifFalse:[
	canvas removeMorph: line.
	
	pos := canvas cursorPoint.
	line := LineMorph from: (line vertices at: 1) to: pos color: Color black width:2.
	
	canvas addMorphBack: line.
	].! !

!LineTool methodsFor: 'drawing' stamp: 'dd 6/6/2012 21:28'!
start
	|pos|
	pos := canvas cursorPoint.
	line := LineMorph from:pos to: pos color: Color black width:2.
	
	canvas addMorphBack: line.! !

!LineTool methodsFor: 'drawing' stamp: 'dd 6/7/2012 11:00'!
view
	^ (LineMorph new).! !


Tool subclass: #MorphTool
	instanceVariableNames: 'morph startPos morphClass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphical-Editor-Base'!

!MorphTool methodsFor: 'install-deinstall' stamp: 'dd 6/6/2012 22:15'!
unregisterEvents
	super unregisterEvents.
	canvas eventHandler forgetDispatchesTo: #start.
	canvas eventHandler forgetDispatchesTo: #move.
	canvas eventHandler forgetDispatchesTo: #end.
	
	! !


!MorphTool methodsFor: 'drawing' stamp: 'dd 6/6/2012 23:36'!
end
	morph := nil.! !

!MorphTool methodsFor: 'drawing' stamp: 'dd 6/7/2012 09:58'!
icon 
	^morph imageForm.! !

!MorphTool methodsFor: 'drawing' stamp: 'dd 6/6/2012 23:35'!
move

 	out ifTrue:[^self]..
	canvas removeMorph: morph.
	morph := morphClass newBounds: ( startPos rect:canvas cursorPoint).
	canvas addMorph: morph.! !

!MorphTool methodsFor: 'drawing' stamp: 'dd 6/6/2012 23:39'!
start
	startPos := canvas cursorPoint.
	morph := morphClass newBounds: ( startPos rect:canvas cursorPoint).
	canvas addMorphBack: morph.! !


!MorphTool methodsFor: 'as yet unclassified' stamp: 'dd 6/6/2012 22:14'!
registerEvents
	super registerEvents.
	canvas on: #mouseDown send: #start to: self.
	canvas on: #mouseMove send: #move to:self.
	canvas on: #mouseUp send: #end to: self.
	
	! !


!MorphTool methodsFor: 'accessing' stamp: 'dd 6/6/2012 23:37'!
morph
	"Answer the value of morph"

	^ morph! !

!MorphTool methodsFor: 'accessing' stamp: 'dd 6/6/2012 23:37'!
morph: anObject
	"Set the value of morph"

	morph := anObject! !

!MorphTool methodsFor: 'accessing' stamp: 'dd 6/6/2012 23:37'!
morphClass
	"Answer the value of morphClass"

	^ morphClass! !

!MorphTool methodsFor: 'accessing' stamp: 'dd 6/6/2012 23:37'!
morphClass: anObject
	"Set the value of morphClass"

	morphClass := anObject! !

!MorphTool methodsFor: 'accessing' stamp: 'dd 6/6/2012 23:37'!
startPos
	"Answer the value of startPos"

	^ startPos! !

!MorphTool methodsFor: 'accessing' stamp: 'dd 6/6/2012 23:37'!
startPos: anObject
	"Set the value of startPos"

	startPos := anObject! !

!MorphTool methodsFor: 'accessing' stamp: 'dd 6/7/2012 11:00'!
view
 ^ (morphClass new)! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

MorphTool class
	instanceVariableNames: ''!

!MorphTool class methodsFor: 'instance creation' stamp: 'dd 6/7/2012 10:02'!
defaultMorphTool
	| e |
	e := MorphTool new.
	e morphClass: Morph.
	e name: 'Default'.
	^e.! !

!MorphTool class methodsFor: 'instance creation' stamp: 'dd 6/7/2012 11:04'!
with: aMorphClass
	| e |
	e := MorphTool new.
	e morphClass: aMorphClass.
	e name: aMorphClass asString.
	^e.! !


Morph subclass: #ToolHandler
	instanceVariableNames: 'editor tools'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphical-Editor-Base'!

!ToolHandler methodsFor: 'initialization' stamp: 'dd 6/7/2012 09:44'!
initialize
	super initialize.
	self tools: OrderedCollection new.! !


!ToolHandler methodsFor: 'accessing' stamp: 'dd 6/7/2012 10:37'!
cr
	Transcript show: 's'! !

!ToolHandler methodsFor: 'accessing' stamp: 'dd 6/7/2012 00:04'!
editor
	"Answer the value of editor"

	^ editor! !

!ToolHandler methodsFor: 'accessing' stamp: 'dd 6/7/2012 00:04'!
editor: anObject
	"Set the value of editor"

	editor := anObject! !

!ToolHandler methodsFor: 'accessing' stamp: 'dd 6/7/2012 10:35'!
handlesMouseDown: evt
	^true! !

!ToolHandler methodsFor: 'accessing' stamp: 'dd 6/7/2012 09:37'!
tools
	"Answer the value of tools"

	^ tools! !

!ToolHandler methodsFor: 'accessing' stamp: 'dd 6/7/2012 09:37'!
tools: anObject
	"Set the value of tools"

	tools := anObject! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

ToolHandler class
	instanceVariableNames: ''!

!ToolHandler class methodsFor: 'as yet unclassified' stamp: 'dd 6/7/2012 11:32'!
createFor: tools with: editor
	|handler|
	handler := ToolHandler new.
	handler tools: tools.
	handler color: Color white.
	handler extent: 1@1.
	handler layoutPolicy: TableLayout new.
	handler listDirection: #leftToRight.
	handler wrapCentering: #topLeft.
	handler wrapDirection: #topToBottom.
	tools do: [:tool|
		|button|
		button := tool view.
		button on:#mouseDown send: #changeTool:a:b: to: editor withValue: tool.
		handler addMorph: button.
	].	
	^handler.! !
